@@ -1,6 +1,6 @@
 import py
-from py.__.misc.rest import convert_rest_html, strip_html_header 
-from py.__.misc.difftime import worded_time 
+
+from py._plugin.pytest_restdoc import convert_rest_html, strip_html_header
 
 html = py.xml.html 
 
@@ -57,24 +57,24 @@ pageTracker._trackPageview();
         
     def fill_menubar(self):
         items = [
-            self.a_docref("install", "download.html"),
-            self.a_docref("contact", "contact.html"),
-            self.a_docref("changelog", "changelog.html"),
-            self.a_docref("faq", "faq.html"),
+            self.a_docref("INSTALL", "install.html"),
+            self.a_docref("CONTACT", "contact.html"),
+            self.a_docref("CHANGELOG", "changelog.html"),
+            self.a_docref("FAQ", "faq.html"),
             html.div(
                 html.h3("py.test:"),
-                self.a_docref("doc index", "test/index.html"),
-                self.a_docref("features", "test/features.html"),
-                self.a_docref("quickstart", "test/quickstart.html"),
-                self.a_docref("tutorials", "test/talks.html"),
-                self.a_docref("plugins", "test/plugin/index.html"),
-                self.a_docref("funcargs", "test/funcargs.html"),
-                self.a_docref("customize", "test/customize.html"),
+                self.a_docref("Index", "test/index.html"),
+                self.a_docref("Quickstart", "test/quickstart.html"),
+                self.a_docref("Features", "test/features.html"),
+                self.a_docref("Funcargs", "test/funcargs.html"),
+                self.a_docref("Plugins", "test/plugin/index.html"),
+                self.a_docref("Customize", "test/customize.html"),
+                self.a_docref("Tutorials", "test/talks.html"),
+                self.a_href("hudson-tests", "http://hudson.testrun.org")
             ),
             html.div(
                 html.h3("supporting APIs:"), 
-                self.a_docref("pylib index", "index.html"),
-                self.a_docref("py.execnet", "execnet.html"),
+                self.a_docref("Index", "index.html"),
                 self.a_docref("py.path", "path.html"),
                 self.a_docref("py.code", "code.html"),
             )
@@ -86,9 +86,10 @@ pageTracker._trackPageview();
         self.menubar = html.div(id=css.menubar, *[
             html.div(item) for item in items])
         version = py.version
+        announcelink = self.a_docref("%s ANN" % version, 
+            "announce/release-%s.html" %(version,))
         self.menubar.insert(0, 
-            html.div("%s" % (py.version), style="font-style: italic;")
-        )
+            html.div(announcelink))
             #self.a_href("%s-%s" % (self.title, py.version), 
             #    "http://pypi.python.org/pypi/py/%s" % version, 
             #id="versioninfo",
@@ -149,7 +150,7 @@ def getrealname(username):
     
 
 class Project:
-    mydir = py.magic.autopath().dirpath()
+    mydir = py.path.local(__file__).dirpath()
     title = "py lib"
     prefix_title = ""  # we have a logo already containing "py lib"
     encoding = 'latin1' 
@@ -286,5 +287,3 @@ def relpath(p1, p2, sep=os.path.sep, back='..', normalize=True):
     if tolist_diff:
         return sep.join([back,]*(backcount-1) + tolist_diff)
     return sep.join([back,]*(backcount) + tolist[commonindex:])
-
-
