@@ -6,8 +6,6 @@ This is a good source for looking at the various reporting hooks.
 import py
 import sys
 
-optionalhook = py.test.mark.optionalhook
-
 def pytest_addoption(parser):
     group = parser.getgroup("terminal reporting", "reporting", after="general")
     group._addoption('-v', '--verbose', action="count", 
@@ -80,7 +78,6 @@ class TerminalReporter:
             file = py.std.sys.stdout
         self._tw = py.io.TerminalWriter(file)
         self.currentfspath = None 
-        self.gateway2info = {}
         self.reportchars = getreportopt(config)
 
     def hasopt(self, char):
@@ -167,52 +164,6 @@ class TerminalReporter:
             #     which garbles our output if we use self.write_line 
             self.write_line(msg)
 
-    @optionalhook
-    def pytest_gwmanage_newgateway(self, gateway, platinfo):
-        #self.write_line("%s instantiated gateway from spec %r" %(gateway.id, gateway.spec._spec))
-        d = {}
-        d['version'] = repr_pythonversion(platinfo.version_info)
-        d['id'] = gateway.id
-        d['spec'] = gateway.spec._spec 
-        d['platform'] = platinfo.platform 
-        if self.config.option.verbose:
-            d['extra'] = "- " + platinfo.executable
-        else:
-            d['extra'] = ""
-        d['cwd'] = platinfo.cwd
-        infoline = ("[%(id)s] %(spec)s -- platform %(platform)s, "
-                        "Python %(version)s "
-                        "cwd: %(cwd)s"
-                        "%(extra)s" % d)
-        self.write_line(infoline)
-        self.gateway2info[gateway] = infoline
-
-    @optionalhook
-    def pytest_testnodeready(self, node):
-        self.write_line("[%s] txnode ready to receive tests" %(node.gateway.id,))
-
-    @optionalhook
-    def pytest_testnodedown(self, node, error):
-        if error:
-            self.write_line("[%s] node down, error: %s" %(node.gateway.id, error))
-
-    @optionalhook
-    def pytest_rescheduleitems(self, items):
-        if self.config.option.debug:
-            self.write_sep("!", "RESCHEDULING %s " %(items,))
-
-    @optionalhook
-    def pytest_looponfailinfo(self, failreports, rootdirs):
-        if failreports:
-            self.write_sep("#", "LOOPONFAILING", red=True)
-            for report in failreports:
-                loc = self._getcrashline(report)
-                self.write_line(loc, red=True)
-        self.write_sep("#", "waiting for changes")
-        for rootdir in rootdirs:
-            self.write_line("### Watching:   %s" %(rootdir,), bold=True)
-
-
     def pytest_trace(self, category, msg):
         if self.config.option.debug or \
            self.config.option.traceconfig and category.find("config") != -1:
@@ -222,24 +173,13 @@ class TerminalReporter:
         self.stats.setdefault('deselected', []).append(items)
 
     def pytest_itemstart(self, item, node=None):
-        if getattr(self.config.option, 'dist', 'no') != "no":
-            # for dist-testing situations itemstart means we 
-            # queued the item for sending, not interesting (unless debugging) 
-            if self.config.option.debug:
-                line = self._reportinfoline(item)
-                extra = ""
-                if node:
-                    extra = "-> [%s]" % node.gateway.id
-                self.write_ensure_prefix(line, extra)
+        if self.config.option.verbose:
+            line = self._reportinfoline(item)
+            self.write_ensure_prefix(line, "") 
         else:
-            if self.config.option.verbose:
-                line = self._reportinfoline(item)
-                self.write_ensure_prefix(line, "") 
-            else:
-                # ensure that the path is printed before the 
-                # 1st test of a module starts running
-
-                self.write_fspath_result(self._getfspath(item), "")
+            # ensure that the path is printed before the 
+            # 1st test of a module starts running
+            self.write_fspath_result(self._getfspath(item), "")
 
     def pytest__teardown_final_logerror(self, report):
         self.stats.setdefault("error", []).append(report)
@@ -273,7 +213,6 @@ class TerminalReporter:
         if not report.passed:
             if report.failed:
                 self.stats.setdefault("error", []).append(report)
-                msg = report.longrepr.reprcrash.message 
                 self.write_fspath_result(report.collector.fspath, "E")
             elif report.skipped:
                 self.stats.setdefault("skipped", []).append(report)
@@ -294,7 +233,7 @@ class TerminalReporter:
         for line in flatten(lines):
             self.write_line(line)
         for i, testarg in enumerate(self.config.args):
-            self.write_line("test object %d: %s" %(i+1, testarg))
+            self.write_line("test path %d: %s" %(i+1, testarg))
 
     def pytest_sessionfinish(self, exitstatus, __multicall__):
         __multicall__.execute() 
@@ -321,12 +260,6 @@ class TerminalReporter:
             else:
                 excrepr.reprcrash.toterminal(self._tw)
 
-    def _getcrashline(self, report):
-        try:
-            return report.longrepr.reprcrash
-        except AttributeError:
-            return str(report.longrepr)[:50]
-
     def _reportinfoline(self, item):
         collect_fspath = self._getfspath(item)
         fspath, lineno, msg = self._getreportinfo(item)
@@ -384,12 +317,11 @@ class TerminalReporter:
             self.write_sep("=", "FAILURES")
             for rep in self.stats['failed']:
                 if tbstyle == "line":
-                    line = self._getcrashline(rep)
+                    line = rep._getcrashline()
                     self.write_line(line)
                 else:    
                     msg = self._getfailureheadline(rep)
                     self.write_sep("_", msg)
-                    self.write_platinfo(rep)
                     rep.toterminal(self._tw)
 
     def summary_errors(self):
@@ -399,22 +331,14 @@ class TerminalReporter:
                 msg = self._getfailureheadline(rep)
                 if not hasattr(rep, 'when'):
                     # collect
-                    msg = "ERROR during collection " + msg
+                    msg = "ERROR collecting " + msg
                 elif rep.when == "setup":
                     msg = "ERROR at setup of " + msg 
                 elif rep.when == "teardown":
                     msg = "ERROR at teardown of " + msg 
                 self.write_sep("_", msg)
-                self.write_platinfo(rep)
                 rep.toterminal(self._tw)
 
-    def write_platinfo(self, rep):
-        if hasattr(rep, 'node'):
-            self.write_line(self.gateway2info.get(
-                rep.node.gateway, 
-                "node %r (platinfo not found? strange)")
-                    [:self._tw.fullwidth-1])
-
     def summary_stats(self):
         session_duration = py.std.time.time() - self._sessionstarttime
 
@@ -429,7 +353,7 @@ class TerminalReporter:
                 parts.append("%d %s" %(len(val), key))
         line = ", ".join(parts)
         # XXX coloring
-        self.write_sep("=", "%s in %.2f seconds" %(line, session_duration))
+        self.write_sep("=", "%s in %.2f seconds" %(line, session_duration), bold=True)
 
     def summary_deselected(self):
         if 'deselected' in self.stats:
@@ -444,16 +368,16 @@ class CollectonlyReporter:
         self.config = config 
         if out is None:
             out = py.std.sys.stdout
-        self.out = py.io.TerminalWriter(out)
+        self._tw = py.io.TerminalWriter(out)
         self.indent = ""
         self._failed = []
 
     def outindent(self, line):
-        self.out.line(self.indent + str(line))
+        self._tw.line(self.indent + str(line))
 
     def pytest_internalerror(self, excrepr):
         for line in str(excrepr).split("\n"):
-            self.out.line("INTERNALERROR> " + line)
+            self._tw.line("INTERNALERROR> " + line)
 
     def pytest_collectstart(self, collector):
         self.outindent(collector)
@@ -470,9 +394,9 @@ class CollectonlyReporter:
 
     def pytest_sessionfinish(self, session, exitstatus):
         if self._failed:
-            self.out.sep("!", "collection failures")
+            self._tw.sep("!", "collection failures")
         for rep in self._failed:
-            rep.toterminal(self.out)
+            rep.toterminal(self._tw)
                 
 
 def repr_pythonversion(v=None):
