@@ -1,7 +1,7 @@
 import py
 import sys
 from py.path import local
-from testing.path import common
+import common
 
 failsonjython = py.test.mark.xfail("sys.platform.startswith('java')")
 failsonjywin32 = py.test.mark.xfail("sys.platform.startswith('java') "
@@ -60,6 +60,17 @@ class TestLocalPath(common.CommonFSTests):
         readonly_dir.remove()
         assert not readonly_dir.check(exists=1)
 
+    def test_remove_routes_ignore_errors(self, tmpdir, monkeypatch):
+        l = []
+        monkeypatch.setattr(py.std.shutil, 'rmtree', 
+            lambda *args, **kwargs: l.append(kwargs))
+        tmpdir.remove()
+        assert not l[0]['ignore_errors'] 
+        for val in (True, False):
+            l[:] = []
+            tmpdir.remove(ignore_errors=val)
+            assert l[0]['ignore_errors'] == val
+
     def test_initialize_curdir(self):
         assert str(local()) == py.std.os.getcwd()
 
@@ -175,6 +186,7 @@ class TestLocalPath(common.CommonFSTests):
         assert l3.strpath == wc.strpath
         assert not hasattr(l3, 'commit')
 
+    @py.test.mark.xfail(run=False, reason="unreliable est for long filenames")
     def test_long_filenames(self, tmpdir):
         if sys.platform == "win32":
             py.test.skip("win32: work around needed for path length limit")
@@ -292,6 +304,12 @@ class TestImport:
         assert obj.x == 42
         assert obj.__name__ == 'execfile' 
 
+    def test_pyimport_dir(self, tmpdir):
+        p = tmpdir.join("hello_123")
+        p.ensure("__init__.py")
+        m = p.pyimport()
+        assert m.__name__ == "hello_123"
+
     def test_pyimport_execfile_different_name(self, path1):
         obj = path1.join('execfile.py').pyimport(modname="0x.y.z")
         assert obj.x == 42
@@ -343,10 +361,13 @@ class TestImport:
         pseudopath = tmpdir.ensure(name+"123.py")
         mod.__file__ = str(pseudopath)
         monkeypatch.setitem(sys.modules, name, mod)
-        excinfo = py.test.raises(EnvironmentError, "p.pyimport()")
-        s = str(excinfo.value)
-        assert "mismatch" in s 
-        assert name+"123" in s 
+        excinfo = py.test.raises(pseudopath.ImportMismatchError, 
+            "p.pyimport()")
+        modname, modfile, orig = excinfo.value.args
+        assert modname == name
+        assert modfile == pseudopath 
+        assert orig == p
+        assert issubclass(pseudopath.ImportMismatchError, ImportError)
 
 def test_pypkgdir(tmpdir):
     pkg = tmpdir.ensure('pkg1', dir=1)
@@ -383,6 +404,10 @@ def test_samefile(tmpdir):
     p = tmpdir.ensure("hello")
     assert p.samefile(p) 
 
+def test_mkdtemp_rootdir(tmpdir):
+    dtmp = local.mkdtemp(rootdir=tmpdir)
+    assert tmpdir.listdir() == [dtmp]
+
 class TestWINLocalPath:
     pytestmark = win32only
 
