@@ -69,6 +69,21 @@ class BaseFunctionalTests:
         assert isinstance(rep.longrepr, ReprExceptionInfo)
         assert str(rep.shortrepr) == "F"
 
+    def test_failfunction_customized_report(self, testdir, LineMatcher):
+        reports = testdir.runitem("""
+            def test_func():
+                assert 0
+        """)
+        rep = reports[1]
+        rep.headerlines += ["hello world"]
+        tr = py.io.TerminalWriter(stringio=True)
+        rep.toterminal(tr)
+        val = tr.stringio.getvalue()
+        LineMatcher(val.split("\n")).fnmatch_lines([
+            "*hello world",
+            "*def test_func():*"
+        ])
+
     def test_skipfunction(self, testdir):
         reports = testdir.runitem("""
             import py
@@ -340,6 +355,36 @@ class TestRaises:
         except py.test.raises.Exception:
             pass
 
+    @py.test.mark.skipif('sys.version < "2.5"')
+    def test_raises_as_contextmanager(self, testdir):
+        testdir.makepyfile("""
+            from __future__ import with_statement
+            import py
+
+            def test_simple():
+                with py.test.raises(ZeroDivisionError) as excinfo:
+                    assert isinstance(excinfo, py.code.ExceptionInfo)
+                    1/0
+                print (excinfo)
+                assert excinfo.type == ZeroDivisionError
+
+            def test_noraise():
+                with py.test.raises(py.test.raises.Exception):
+                    with py.test.raises(ValueError):
+                           int()
+
+            def test_raise_wrong_exception_passes_by():
+                with py.test.raises(ZeroDivisionError):
+                    with py.test.raises(ValueError):
+                           1/0
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines([
+            '*3 passed*',
+        ])
+
+
+
 def test_pytest_exit():
     try:
         py.test.exit("hello")
@@ -405,3 +450,4 @@ def test_pytest_cmdline_main(testdir):
     s = popen.stdout.read()
     ret = popen.wait()
     assert ret == 0
+
